@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2011
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -30,11 +30,11 @@
 #include <omp.h>
 #include <config.h>
 #include "timbl/TimblAPI.h"
-#include "timbl/StringOps.h"
 #include "dimbl/DimProcs.h"
 
 using namespace std;
 using namespace Timbl;
+using namespace TiCC;
 
 //#define DEBUG 1
 
